# Nuclia CLI/SDK

This SDK/CLI is designed to facilitate use of the Nuclia API.

There are two developer experiences:

- CLI: by using the cli `nuclia` you can interact with Nuclia via command line
- SDK: Using python you can replicate each command using the same structure

It requires Python (≥3.8) and can be installed with:

```sh
pip install nuclia
```

## Getting started

First steps should be:

- [Authentication](02-auth.md)
- [Setting KnowledgeBox or NUA key](03-default.md).

## Use Cases

- [Upload files](04-upload.md)
- [Upload url](04-upload.md)
- [Upload text](04-upload.md)
- [Upload conversation](07-conversation.md)
- [Search](06-search.md)
- [Extract information from a file](05-extract.md)
- [Import/export knowledge boxes](08-import-export.md)
- Detect Entities
- [Get embedding from text](05-extract.md)
- Get answer from a context
